@@ -113,8 +113,8 @@ UnifixedContCont <- function(Dataset, Surr, True, Treat, Trial.ID, Pat.ID, Model
     set.seed(Seed)
     Indicator <- sample(obs, N.total, replace=TRUE)  
     Seed <- Seed + 1
-    Sample.boot.S <- data.frame(dataS[Indicator,])
-    Sample.boot.T <- data.frame(dataT[Indicator,])
+    Sample.boot.S <- data.frame(dataS[Indicator,], stringsAsFactors = TRUE)
+    Sample.boot.T <- data.frame(dataT[Indicator,], stringsAsFactors = TRUE)
     Sample.boot.S <- na.exclude(Sample.boot.S[order(Sample.boot.S$Pat.ID),])   
     Sample.boot.T <- na.exclude(Sample.boot.T[order(Sample.boot.T$Pat.ID),])
     if (Model==c("Full") | Model==c("SemiReduced")){
@@ -135,7 +135,7 @@ UnifixedContCont <- function(Dataset, Surr, True, Treat, Trial.ID, Pat.ID, Model
   Var.Boot.r <- var(Boot.r)
   Indiv.R2.lb <- max(0, R2ind + qnorm(Alpha/2)*sqrt(Var.Boot.r))
   Indiv.R2.ub <- min(1, R2ind - qnorm(Alpha/2)*sqrt(Var.Boot.r))
-  Indiv.R2 <- data.frame(cbind(R2ind, sqrt(Var.Boot.r), Indiv.R2.lb, Indiv.R2.ub))
+  Indiv.R2 <- data.frame(cbind(R2ind, sqrt(Var.Boot.r), Indiv.R2.lb, Indiv.R2.ub), stringsAsFactors = TRUE)
   colnames(Indiv.R2) <- c("R2 Indiv", "Standard Error", "CI lower limit", "CI upper limit")
   rownames(Indiv.R2) <- c(" ")
   
@@ -145,8 +145,8 @@ UnifixedContCont <- function(Dataset, Surr, True, Treat, Trial.ID, Pat.ID, Model
   for (j in 1:Number.Bootstraps){
     obs <- c(1:N.total)
     Indicator <- sample(obs, N.total, replace=TRUE) 
-    Sample.boot.S <- data.frame(dataS[Indicator,])
-    Sample.boot.T <- data.frame(dataT[Indicator,])
+    Sample.boot.S <- data.frame(dataS[Indicator,], stringsAsFactors = TRUE)
+    Sample.boot.T <- data.frame(dataT[Indicator,], stringsAsFactors = TRUE)
     Sample.boot.S <- na.exclude(Sample.boot.S[order(Sample.boot.S$Pat.ID),])      
     Sample.boot.T <- na.exclude(Sample.boot.T[order(Sample.boot.T$Pat.ID),])
     Boot.model.S <- lm(outcome ~ as.factor(Trial.ID):Treat, data=Sample.boot.S)
@@ -160,7 +160,7 @@ UnifixedContCont <- function(Dataset, Surr, True, Treat, Trial.ID, Pat.ID, Model
   Var.Boot.r <- var(Boot.r)
   Indiv.R.lb <- max(0, Rind + qnorm(Alpha/2)*sqrt(Var.Boot.r))
   Indiv.R.ub <- min(1, Rind - qnorm(Alpha/2)*sqrt(Var.Boot.r))
-  Indiv.R <- data.frame(cbind(Rind, sqrt(Var.Boot.r), Indiv.R.lb, Indiv.R.ub))
+  Indiv.R <- data.frame(cbind(Rind, sqrt(Var.Boot.r), Indiv.R.lb, Indiv.R.ub), stringsAsFactors = TRUE)
   colnames(Indiv.R) <- c("R Indiv", "Standard Error", "CI lower limit", "CI upper limit") 
   rownames(Indiv.R) <- c(" ") 
   
@@ -172,17 +172,17 @@ UnifixedContCont <- function(Dataset, Surr, True, Treat, Trial.ID, Pat.ID, Model
   rho_lb <- max(0, (exp(2*(Z_T0S0-(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))-1)/(exp(2*(Z_T0S0-(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))+1))
   rho_ub <- min(1, (exp(2*(Z_T0S0+(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))-1)/(exp(2*(Z_T0S0+(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))+1))
   rho_sd <- sqrt((1-T0S0**2)/(N.total-2))
-  rho_results_T0S0 <- data.frame(cbind(T0S0, rho_sd , rho_lb, rho_ub))
+  rho_results_T0S0 <- data.frame(cbind(T0S0, rho_sd , rho_lb, rho_ub), stringsAsFactors = TRUE)
   colnames(rho_results_T0S0) <- c("Estimate", "Standard Error", "CI lower limit", "CI upper limit")
   rownames(rho_results_T0S0) <- c(" ")
   Z_T1S1 <- .5*log((1+T1S1)/(1-T1S1)) 
   rho_lb <- max(0, (exp(2*(Z_T1S1-(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))-1)/(exp(2*(Z_T1S1-(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))+1))
   rho_ub <- min(1, (exp(2*(Z_T1S1+(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))-1)/(exp(2*(Z_T1S1+(qnorm(1-Alpha/2)*sqrt(1/(N.total-3)))))+1))
   rho_sd <- sqrt((1-T1S1**2)/(N.total-2))
-  rho_results_T1S1 <- data.frame(cbind(T1S1, rho_sd , rho_lb, rho_ub))
+  rho_results_T1S1 <- data.frame(cbind(T1S1, rho_sd , rho_lb, rho_ub), stringsAsFactors = TRUE)
   colnames(rho_results_T1S1) <- c("Estimate", "Standard Error", "CI lower limit", "CI upper limit")
   rownames(rho_results_T1S1) <- c(" ")
-  Cor.Endpoints <- data.frame(rbind(rho_results_T0S0, rho_results_T1S1))
+  Cor.Endpoints <- data.frame(rbind(rho_results_T0S0, rho_results_T1S1), stringsAsFactors = TRUE)
   rownames(Cor.Endpoints) <- c("r_T0S0", "r_T1S1")
   colnames(Cor.Endpoints) <- c("Estimate", "Standard Error", "CI lower limit", "CI upper limit")
   
