@@ -11,11 +11,11 @@ summary.TwoStageSurvSurv <- function(object, ..., Object){
       " (", format(round(sd((Object$Results.Stage.1$Trial.Size)), 4), nsmall = 4), ")", 
       "  [min: ", min((Object$Results.Stage.1$Trial.Size)), "; max: ",  max((Object$Results.Stage.1$Trial.Size)), "]", sep="")
   
-  cat("\n\n\n# R^2_{trial} results")
+  cat("\n\n\n# R^2_{ht} results")
   cat("\n#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~")
   cat("\n\n")
-  print(format(round(Object$Trial.R2, 4), nsmall = 4))
+  print(format(round(Object$R2.ht, 4), nsmall = 4))
   cat("\n")
-  print(format(round(Object$Trial.R, 4), nsmall = 4))
+  print(format(round(Object$R.ht, 4), nsmall = 4))
   cat("\n")
   }
